@@ -20,6 +20,7 @@ import (
 	appsv1 "k8s.io/api/apps/v1"
 	corev1 "k8s.io/api/core/v1"
 	extv1 "k8s.io/apiextensions-apiserver/pkg/apis/apiextensions/v1"
+	"k8s.io/apimachinery/pkg/api/resource"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 )
 
@@ -90,6 +91,12 @@ func CreateOperatorContainer(name, image, verbosity string, pullPolicy corev1.Pu
 		Name:            name,
 		Image:           image,
 		ImagePullPolicy: pullPolicy,
+		Resources: corev1.ResourceRequirements{
+			Requests: corev1.ResourceList{
+				corev1.ResourceCPU:    resource.MustParse("10m"),
+				corev1.ResourceMemory: resource.MustParse("150Mi"),
+			},
+		},
 	}
 }
 
@@ -124,6 +131,22 @@ func CreateOperatorEnvVar(repo, deployClusterResources, operatorImage, provision
 			Name:  "PULL_POLICY",
 			Value: pullPolicy,
 		},
+		{
+			Name: "INSTALLER_PART_OF_LABEL",
+			ValueFrom: &corev1.EnvVarSource{
+				FieldRef: &corev1.ObjectFieldSelector{
+					FieldPath: "metadata.labels['app.kubernetes.io/part-of']",
+				},
+			},
+		},
+		{
+			Name: "INSTALLER_VERSION_LABEL",
+			ValueFrom: &corev1.EnvVarSource{
+				FieldRef: &corev1.ObjectFieldSelector{
+					FieldPath: "metadata.labels['app.kubernetes.io/version']",
+				},
+			},
+		},
 	}
 }
 
